*================== PROGRAM: PSI17_PROV_OBSERVED.SAS ===================;
*
*  TITLE: PROGRAM PSI17_PROV_OBSERVED.SAS CALCULATES OBSERVED PROVIDER LEVEL RATES 
*         FOR AHRQ PATIENT SAFETY INDICATOR - PSI 17: BIRTH TRAUMA RATE - INJURY TO NEONATE
*
*  DESCRIPTION:
*         USES PROC SUMMARY TO CALCULATE POPULATION AND OBSERVED RATES FOR
*         PATIENT SAFETY INDICATOR 17 ACROSS STRATIFIERS.
*         PROGRAM USES HOSPID, BWHTCAT, AGEDCAT, PAGECAT, SEXCAT, 
*         PAYCAT, RACECAT.
*         THIS INDICATOR IS ALSO INCLUDED IN THE PEDIATRIC  
*         QUALITY INDICATOR MODULE.
*
*  VERSION: AHRQ QI v7.0.1 BETA
*  RELEASE DATE: DECEMBER 2017
*
*=======================================================================;

*PATHNAME specifies the location of the PSI17 folder which includes 
          Programs, SASdata, and Macros subfolders;
%LET PATHNAME=c:\Pathname\PSI17;                        *<==USER MUST modify;
filename CONTROL "&PATHNAME.\Programs\PSI17_ALL_CONTROL.SAS"; 

%include CONTROL;

title2 'PROGRAM: PSI17_PROV_OBSERVED';
title3 'AHRQ PATIENT SAFETY INDICATOR 17: CALCULATE OBSERVED PROVIDER LEVEL RATES';

 * ------------------------------------------------------------------ ;
 * --- PROVIDER LEVEL SUMMARY USING PSI17_ALL_MEASURES.SAS OUTPUT --- ;
 * ------------------------------------------------------------------ ;

 data   TEMP0;
   set  OUTMSR.&OUTFILE_MEAS.;
   onewgt=1;
 run;

 * ---------------------------------------------------------------- ;
 * --- PATIENT SAFETY INDICATOR (PSI) NAMING CONVENTION:        --- ;
 * --- THE FIRST LETTER IDENTIFIES THE INDICATOR AS ONE OF      --- ;
 * --- THE FOLLOWING:                                    
                (T) NUMERATOR ("TOP")
                (P) POPULATION ("POP")
                (O) OBSERVED RATES
 * --- THE SECOND LETTER IDENTIFIES THE TYPE OF INDICATOR WITH  --- ;
 * --- 'P' FOR PROVIDER LEVEL. THE NEXT TWO CHARACTERS ARE      --- ;
 * --- 'PS'. THE LAST TWO DIGITS ARE 17 FOR INDICATOR PSI 17.   --- ;
 * ---------------------------------------------------------------- ;

 proc   summary data=TEMP0;
   class  HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;
   var    TPPS17;
   weight onewgt;
   output OUT=&OUTFILE_PROVOBS.
        SUM (TPPS17)=
        SUMWGT (TPPS17)= PPPS17
        MEAN(TPPS17)= OPPS17;
 run;

 proc   sort data=&OUTFILE_PROVOBS.;
   by HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT;
 run;

 data   OUTPOBS.&OUTFILE_PROVOBS.;
   set  &OUTFILE_PROVOBS. (WHERE=(_TYPE_ &TYPELVLP))
;

   label
     TPPS17 = 'PSI 17 Birth Trauma Rate - Injury to Neonate (Numerator)'
     PPPS17 = 'PSI 17 Birth Trauma Rate - Injury to Neonate (Population)'
     OPPS17 = 'PSI 17 Birth Trauma Rate - Injury to Neonate (Observed)'
 _TYPE_ = 'STRATIFICATION LEVEL'
  ;
 drop _FREQ_ ;

 run;

 * -------------------------------------------------------------- ;
 * --- CONTENTS AND MEANS OF PROVIDER OBSERVED MEANS FILE ------- ;
 * -------------------------------------------------------------- ;

 proc   contents data=OUTPOBS.&OUTFILE_PROVOBS. POSITION;
 run;

 proc   means data=OUTPOBS.&OUTFILE_PROVOBS. (WHERE=(_TYPE_ IN (64))) N NMISS MIN MAX MEAN SUM NOLABELS;
   title4 "SUMMARY OF PROVIDER-LEVEL RATES (_TYPE_=64)";
 run;

 * -------------------------------------------------------------- ;
 * --- PRINT PROVIDER OBSERVED MEANS FILE TO SAS OUTPUT --------- ;
 * -------------------------------------------------------------- ;

 %MACRO PRT2;

 %IF &PRINT. = 1 %THEN %DO;

 %MACRO PRT(PD,TEXT,VOLUME);

 proc   print data=OUTPOBS.&OUTFILE_PROVOBS. label SPLIT='*';
 %IF &VOLUME=0 %THEN %DO;
   var    HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT TP&PD. PP&PD. OP&PD. ;
   label HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TP&PD.   = "TP&PD.*(Numerator)"
       PP&PD.   = "PP&PD.*(Denominator)"
       OP&PD.   = "OP&PD.*(Observed)"
       ;
   format BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TP&PD. PP&PD. 13.0 OP&PD. 8.6;
 %END;
 %ELSE %DO;
   var    HOSPID BWHTCAT AGEDCAT PAGECAT SEXCAT PAYCAT RACECAT TP&PD.    ;
   label HOSPID  = "HOSPID"
       BWHTCAT = "BWHTCAT"
       AGEDCAT = "AGEDCAT"
       PAGECAT = "PAGECAT"
       SEXCAT  = "SEXCAT"
       PAYCAT  = "PAYCAT"
       RACECAT = "RACECAT"
       TP&PD.   = "TP&PD.*(Numerator)"
       ;
   format BWHTCAT BWHTCAT.
        AGEDCAT AGEDCAT.
        PAGECAT PAGECAT.
        SEXCAT SEXCAT.
        PAYCAT PAYCAT.
        RACECAT RACECAT.
        TP&PD. 13.0;
 %END;
   title4 "Indicator &PD.: &TEXT";

 run;

 %MEND PRT;

 %PRT(PS17,Birth Trauma Rate - Injury to Neonate,0);

 %END;

 %MEND PRT2;

 %PRT2;

 * -------------------------------------------------------------- ;
 * --- WRITE SAS OUTPUT DATA SET TO COMMA-DELIMITED TEXT FILE --- ;
 * --- FOR EXPORT INTO SPREADSHEETS ----------------------------- ;
 * -------------------------------------------------------------- ;

 %MACRO TEXTP1;
 %if &TXTPOBS. = 1  %then %do;
 data _NULL_;
 set OUTPOBS.&OUTFILE_PROVOBS.;
 file P17TXTPO lrecl=2000 ;
 if _N_=1 then do;

  put "Hosp Id" "," "Age" "," "Sex" "," "Payer" "," "Race" "," "Type" ","
 "TPPS17" "," "PPPS17" "," "OPPS17" ;
 end;
 
 put HOSPID 13. "," AGECAT 3. "," SEXCAT 3. "," PAYCAT 3. "," RACECAT 3. "," _TYPE_ 2.  ","
 (TPPS17) (7.0 ",")
  ","
 (PPPS17) (13.2 ",")
 ","
 (OPPS17) (12.10 ",")
 ;
 run;

 %END;

 %MEND TEXTP1;

 %TEXTP1;
